#!/usr/bin/env python
# -*- coding: utf-8 -*-

__title__ = 'baidupcsapi'
__version__ = '0.3.2'
__author__ = 'latyas'
__license__ = 'MIT'

from .api import PCS
